@@ -41,7 +41,7 @@ class Repository:
         model = self.update(entity_from_database=model_from_database, entity=data)
 
         if model not in self.session:
-            self.session.add(model)
+            self.session.merge(model)
         # else:
         #     self.session.merge(model)
 
